@@ -70,7 +70,6 @@ def validate_schema(schema, **kwargs):
             """
             d = {}
             for key, value in bottle_form.iterallitems():
-                print key,value
                 if key not in d:
                     d[key] = value
                     if key in schema.get('properties') and not isinstance(value, list):
@@ -90,6 +89,7 @@ def validate_schema(schema, **kwargs):
                 instance = data
             else:
                 data = request.forms
+                data.update(request.query)
                 instance = convert_to_dict(data)
             request.cleaned_data = instance
             errors = jsonvalidation.get_error_dictionary(
