@@ -48,7 +48,7 @@ class SessionAbstract(object):
         # initialize logger
         self.log = Log.get_instance()
         # get config
-        self.config = Config.get_instance()
+        self.config = Config()
         # name of session cookie
         self.name = self.config.session.get('name', 'DECANTERSESID')
         # session lifetime
@@ -70,6 +70,9 @@ class SessionAbstract(object):
     def read(self):
         raise NotImplementedError("read method not implemented")
 
+    def close(self):
+        raise NotImplementedError("close method not implemented")
+
     def get(self, key, default=None):
         return self.data.get(key, default)
 
@@ -214,5 +217,12 @@ class ExpressSession(SessionAbstract):
         response.set_cookie(self.name, urllib.quote_plus(
             self.crypt.encrypt(phpserialize.dumps(self.cookie))), **params)
 
+    def close(self):
+        try:
+            self.redis.close()
+        except Exception as e:
+            print("Error closing redis connection: {0}".format(e))
+            self.log.error("Error closing redis connection: {0}".format(e))
+
     def __str__(self):
         return ':'.join([self.cookie['session_id'] if self.cookie['session_id'] else '', self.data.__str__()])
